#
# spec file for package google-osconfig-agent
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global provider        github
%global provider_tld    com
%global project         GoogleCloudPlatform
%global repo            osconfig
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}

Name:           google-osconfig-agent
Version:        20210316.00
Release:        1.8.2
Summary:        Google Cloud Guest Agent
License:        Apache-2.0
Group:          System/Daemons
URL:            https://%{provider_prefix}
Source0:        %{repo}-%{version}.tar.gz
Source1:        vendor.tar.gz
Source2:        rpmlintrc
BuildRequires:  go1.14
Requires:       google-guest-configs
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  golang-packaging

%{go_nostrip}
%{go_provides}

%description
Google Cloud OSConfig Agent

%prep
%setup -q -n %{repo}-%{version}
%setup -q -D -T -a 1 -n %{repo}-%{version}

%build
%goprep %{import_path}
CGO_ENABLED=0 go build -ldflags="-s -w -X main.version=%{version}-%{release}" -mod=vendor -o google_osconfig_agent

%install
install -d %{buildroot}%{_bindir}
install -d %{buildroot}%{_sbindir}
install -d %{buildroot}/etc/osconfig
install -p -m 0755 google_osconfig_agent %{buildroot}%{_bindir}/google_osconfig_agent
install -d %{buildroot}%{_unitdir}
install -p -m 0644 %{name}.service %{buildroot}%{_unitdir}
for srv_name in %{buildroot}%{_unitdir}/*.service; do rc_name=$(basename -s '.service' $srv_name); ln -s service %{buildroot}%{_sbindir}/rc$rc_name; done

%pre
    %service_add_pre google-osconfig-agent.service

%preun
    %service_del_preun google-osconfig-agent.service

%post
    %service_add_post google-osconfig-agent.service

%postun
    %service_del_postun google-osconfig-agent.service

%files
%defattr(0644,root,root,0755)
%doc README.md
%license LICENSE THIRD_PARTY_LICENSES
%attr(0755,root,root) %{_bindir}/*
%attr(0755,root,root) %{_sbindir}/*
%{_unitdir}/%{name}.service

%changelog
* Wed Mar 31 2021 adrian.glaubitz@suse.com
- Update to version 20210316.00 (bsc#1183414, bsc#1183415)
  * ExecResource: fix bug in return code handling (#295)
  * Fix ExecResource permissions, add logs to fetcher (#294)
  * e2e_tests: Fix ubuntu proposed family (#293)
  * e2e_tests: add proposed debian images to head tests (#292)
  * Fix exec_resource for config task, add minimal unit test (#291)
  * Change util.WriteFile to AtomicWriteFileStream (#289)
  * Merge development branch into master (#288)
  * Create util.TempFile to work nicely with Windows (#287)
  * Fix copy step write (#286)
  * Fix error on linux lock (#285)
  * Ensure we cleanup on error in AtomicWrite (#284)
  * Make writes atomic, add unused "allowDowngrades" option
    to apt, fix a few recipe issues (#283)
  * update reviewers (#282)
  * update apt package lists before running installs (#281)
  * Simplify build tags for COS package (#280)
* Tue Jan 12 2021 adrian.glaubitz@suse.com
- Update to version 20210112.00
  * Fix builds for ppc and s390x (#274)
  * Minor updates to tests and additional debug logging (#272)
  * Add Ubuntu 2004 to tests (#271)
  * Make sure we stop tickers (#270)
  * Drop Windows 1903 and CentOS 6 from tests (#269)
  * Pin el6 tests to last published image as it is EOL (#267)
  * support cos (#266)
* Tue Nov 24 2020 adrian.glaubitz@suse.com
- Update to version 20201117.00 (bsc#1179031, bsc#1179032)
  * Ignore Unavailable erros on stream receive (#260)
  * Update test Windows images (#259)
  * update ReportInventory e2e test regexes (#255)
  * Don't return on a windows update error (#254)
  * use retryutil for ReportInventory calls (#253)
  * add additional debug logging for ReportInventory request payload for e2e tests (#252)
  * stop logging instance identity token as part of ReportInventory request and remove
    feature-flag setting in OSInventoryReporting e2e tests (#251)
  * complete ExecTask as no-op when the ExecStepConfig doesn't match the OS (#250)
  * Add software recipe tests for COS (#249)
  * remove feature flag for inventory reporting (#243)
  * Force yum to never colorize output (#247)
  * Add sleep after Unavailable errors for agentendpoint (#241)
  * Ensure we record epoch for rpm packages (#242)
  * Make inventory WUAUpdates call spawn a new process,
    retry on metadata unmarshal error (#239)
  * add debug logging for report inventory response (#240)
  * add initial e2e tests for inventory reporting (#237)
  * Report installed packages on COS (#236)
* Thu Oct  8 2020 adrian.glaubitz@suse.com
- Update to version 20200929.00
  * Merge inventory feature from development (#235)
  * Set full version during Windows build (#234)
- Remove Provides/Obsoletes for google-compute-engine-init
* Tue Sep 15 2020 adrian.glaubitz@suse.com
- Initial build (bsc#1176427, bsc#1178249, jsc#ECO-2702, jsc#PM-2203)
  + Version 20200908.00
